@@ -1,5 +1,12 @@
+import ctypes
+import sys
+flags = sys.getdlopenflags()
+sys.setdlopenflags(flags | ctypes.RTLD_GLOBAL)
+
 import cqlat_utils as cu
 
+sys.setdlopenflags(flags)
+
 from qlat_utils.timer import *
 
 from qlat_utils.cache import *
@@ -23,3 +30,7 @@ from qlat_utils.qplot import \
         plot_save, plot_view, \
         gnuplot_png_density, \
         display_img
+
+from qlat_utils.parallel import *
+
+from qlat_utils.get_include_dir import *
